@@ -25,8 +25,11 @@ def classification_metrics(y_true, y_pred, y_proba=None) -> Dict[str, float]:
     return out
 
 def regression_metrics(y_true, y_pred) -> Dict[str, float]:
+    # Avoid 'squared=False' for max compatibility
+    mse = float(mean_squared_error(y_true, y_pred))
+    rmse = mse ** 0.5
     return {
         "r2": float(r2_score(y_true, y_pred)),
-        "rmse": float(mean_squared_error(y_true, y_pred, squared=False)),
+        "rmse": rmse,
         "mae": float(mean_absolute_error(y_true, y_pred)),
     }
